@@ -12,9 +12,9 @@
 
 #' Extract monthly levels information from the HYDAT database
 #'
-#' Tidy data of monthly river or lake levels information from the DLY_LEVELS HYDAT table. \code{station_number} and
-#'   \code{prov_terr_state_loc} can both be supplied. If both are omitted all values from the \code{hy_stations} table are returned.
-#'   That is a large vector for \code{hy_monthly_levels}.
+#' Tidy data of monthly river or lake levels information from the DLY_LEVELS HYDAT table. `station_number` and
+#'   `prov_terr_state_loc` can both be supplied. If both are omitted all values from the `hy_stations` table are returned.
+#'   That is a large vector for `hy_monthly_levels`.
 #'
 #' @inheritParams hy_stations
 #' @param start_date Leave blank if all dates are required. Date format needs to be in YYYY-MM-DD. Date is inclusive.
@@ -60,7 +60,7 @@ hy_monthly_levels <- function(station_number = NULL,
   ## Read in database
   hydat_con <- hy_src(hydat_path)
   if (!dplyr::is.src(hydat_path)) {
-    on.exit(hy_src_disconnect(hydat_con))
+    on.exit(hy_src_disconnect(hydat_con), add = TRUE)
   }
 
   ## Determine which stations we are querying
