@@ -42,4 +42,9 @@ test_that("hy_stn_op_schedule returns a dataframe", {
   class = "tbl_df")
 })
 
+
+test_that("hy_stn_data_range contains properly coded NA's",{
+  expect_true(is.na(hy_stn_data_range(hydat_path = hy_test_db())$SED_DATA_TYPE[1]))
+})
+
 ##Not testing STN_DATUM_UNRELALTED because there are so few stations in the database
